<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX Xestor de usuarios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Administración</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Engadir a un novo usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Engadir conta de usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Enter password for new user</source>
        <translation>Inserir contrasinal para o novo usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>password</source>
        <translation>contrasinal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Reenter password for new user</source>
        <translation>Reintroducir o contrasinal para o novo usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>confirm password</source>
        <translation>confirmar o contrasinal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>Username of new user</source>
        <translation>Nome do usuario do novo usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>User login name:</source>
        <translation>Nome de acceso do usuario:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <location filename="../mainwindow.ui" line="466"/>
        <source>Enter username of new user</source>
        <translation>Introducir o nome do usuario do novo usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="223"/>
        <location filename="../mainwindow.ui" line="472"/>
        <source>username</source>
        <translation>nome do usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <location filename="../mainwindow.ui" line="258"/>
        <source>Password for new user</source>
        <translation>COntrasinal para o novo usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Confirm user password:</source>
        <translation>Confirmar o contrasinal do usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>User password:</source>
        <translation>Contrasinal do usuario:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="271"/>
        <source>Grant this user administrative rights to the system (sudo)</source>
        <translation>Concede a este usuario dereitos administrativos no sistema (sudo)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>Delete User Account</source>
        <translation>Eliminar conta do usuari</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Select user</source>
        <translation>Seleccionar usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <location filename="../mainwindow.ui" line="1436"/>
        <source>Select user to delete</source>
        <translation>Seleccionar usuario para eliminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>User to delete:</source>
        <translation>Usuario a eliminar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="374"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Tamén eliminar o directorio de home do usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Delete user home directory</source>
        <translation>Eliminar o directorio de home do usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="396"/>
        <source>Rename User Account</source>
        <translation>Renomear a conta do usuari</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <location filename="../mainwindow.ui" line="570"/>
        <source>Select user to modify:</source>
        <translation>Seleccionar usuario para modificar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>New user name:</source>
        <translation>Novo nome do usuario:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Change User Password</source>
        <translation>Cambiar o contrasinal do usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>new password</source>
        <translation>novo contrasinal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="535"/>
        <source>Confirm new password:</source>
        <translation>Confirmar novo contrasinal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>confirm new password</source>
        <translation>confirmar novo contrasina</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="586"/>
        <source>New user password:</source>
        <translation>Contrasinal do novo usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Options</source>
        <translation>Opcións</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="623"/>
        <source>Repair a user configuration</source>
        <translation>Reparar a configuración do usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <location filename="../mainwindow.ui" line="1393"/>
        <source>Modify User Account</source>
        <translation>Modificar a conta do usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="669"/>
        <location filename="../mainwindow.ui" line="685"/>
        <source>Select user to repair</source>
        <translation>Seleccionar usuario para reparar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <location filename="../mainwindow.ui" line="1445"/>
        <source>User to change:</source>
        <translation>Usuario a modificar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="717"/>
        <source>Restore Defaults</source>
        <translation>Restablecer a configuración predeterminada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="738"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Restaurar as configuracións do navegador para as predeterminadas do MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="744"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Configuración do Mozilla (Iceweasel ou Firefox(</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="754"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Restaurar os membros do grupo para os predeterminados de MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>Group memberships</source>
        <translation>Membros do grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="773"/>
        <source>Change Autologin Settings</source>
        <translation>Cambiar a configuracion do inicio de sesión automático</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="779"/>
        <source>Log in automatically</source>
        <translation>Iniciar sesión automaticamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="786"/>
        <source>Require password to log in</source>
        <translation>Requerido contrasinal para iniciar sesión</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="801"/>
        <source>Copy/Sync</source>
        <translation>Copiar/Sincronizar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="828"/>
        <source>Copy Between Desktops</source>
        <translation>Copiar entre escritorios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="855"/>
        <location filename="../mainwindow.ui" line="922"/>
        <source>Select desktop to copy from</source>
        <translation>Seleccionar escritorio de onde copiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="868"/>
        <source>Select to only copy files</source>
        <translation>Seleccionar para só copiar ficheiros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="871"/>
        <source>Copy only</source>
        <translation>Só copiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="887"/>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select desktop to copy to</source>
        <translation>Seleccionar o escritorio para onde copiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="909"/>
        <source>Copy to:</source>
        <translation>Copiar a:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="931"/>
        <source>Copy from:</source>
        <translation>Copiar de:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="944"/>
        <source>Select to copy and then delete differences</source>
        <translation>Seleccionar para copiar e de seguida eliminar diferenzas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Sync</source>
        <translation>Sincronizar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="993"/>
        <source>Select to copy/sync Shared</source>
        <translation>Seleccionar para copiar/sincronizar intercambiadas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="996"/>
        <source>Shared folder</source>
        <translation>Cartafol compartido</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1009"/>
        <source>Select to copy/sync entire home</source>
        <translation>Seleccionar para copiar/sincronizar todo o cartafol persoal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1012"/>
        <source>Entire home</source>
        <translation>Todo o cartafol persaol</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1028"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Seleccionar par copiar/sincronizar a configuración do navegador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1031"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Configuración para Mozilla (Iceweasel ou Firefox)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1044"/>
        <source>Select to copy/sync Documents</source>
        <translation>Seleccionar para copiar/sincronizar o cartafol Documentos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1047"/>
        <source>Documents folder</source>
        <translation>Cartafol Documentos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1054"/>
        <source>What to copy/sync:</source>
        <translation>Que copiar/sincronizar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1070"/>
        <source>Progress</source>
        <translation>Progreso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1100"/>
        <location filename="../mainwindow.ui" line="1116"/>
        <source>Status of the changes</source>
        <translation>Estado dos cambios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1119"/>
        <source>Status:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1135"/>
        <source>Progress of the changes</source>
        <translation>Progreso dos cambios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1172"/>
        <source>Add/Remove Groups</source>
        <translation>Engadir/eliminar grupos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1184"/>
        <source>Add Group</source>
        <translation>Engadir grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1211"/>
        <source>Enter name of new group</source>
        <translation>Introduza o nome do novo grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1217"/>
        <source>groupname</source>
        <translation>nomedogrupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1227"/>
        <source>Create a group with GID &gt; 1000</source>
        <translation>Crear un grupo con GID &gt; 1000</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1230"/>
        <source>Create a user-level group</source>
        <translation>Crear un grupo de nivel de usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enter name of new group&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Introduza o nome do novo grupo&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1262"/>
        <source>Group name:</source>
        <translation>Nome do grupo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1281"/>
        <source>Delete Group</source>
        <translation>Eliminar grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1350"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select group to delete&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Selecciona o grupo a eliminar&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1359"/>
        <source>Select group to delete:</source>
        <translation>Selecciona o grupo a eliminar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1366"/>
        <source>*Please doublecheck your selections before applying, removing a wrong group can break your system.</source>
        <translation>*Por favor, verifique as suas seleções antes de aplicar, remover um grupo errado pode danificar o seu sistema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1381"/>
        <source>Group Membership</source>
        <translation>Membros do grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Grupos a que o usuario pertence (cambiar os grupos marcando ou desmarcando as respectivas caixas):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1478"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system. If you made a mistake, use restore group membership in Options tab to restore the defaults.</source>
        <translation>*Por favor, verifique as súas seleccións antes de aplicar, asignar membros incorrectos a un grupo pode romper o seu sistema. Se cometeu un erro, use a opción de restaurar membros do grupo na lapela de Opcións para restaurar os valores predeterminados.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1507"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select user to change&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Selecciona o usuario a cambiar&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1583"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancelar os cambios e saír</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1586"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1593"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1634"/>
        <source>Display help </source>
        <translation>Amosar axuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1637"/>
        <source>Help</source>
        <translation>Axuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1644"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>Apply any changes</source>
        <translation>Aplicar cambios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1654"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1661"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1668"/>
        <source>About this application</source>
        <translation>Sobre esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1671"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1678"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="157"/>
        <location filename="../mainwindow.cpp" line="165"/>
        <location filename="../mainwindow.cpp" line="192"/>
        <location filename="../mainwindow.cpp" line="810"/>
        <location filename="../mainwindow.cpp" line="840"/>
        <location filename="../mainwindow.cpp" line="997"/>
        <location filename="../mainwindow.cpp" line="1064"/>
        <location filename="../mainwindow.cpp" line="1071"/>
        <location filename="../mainwindow.cpp" line="1076"/>
        <location filename="../mainwindow.cpp" line="1081"/>
        <location filename="../mainwindow.cpp" line="1086"/>
        <source>none</source>
        <translation>ningunha</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="142"/>
        <location filename="../mainwindow.cpp" line="774"/>
        <location filename="../mainwindow.cpp" line="1004"/>
        <location filename="../mainwindow.cpp" line="1013"/>
        <source>browse...</source>
        <translation>navegador...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="208"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>A configuración do usuario será reparada. Pechar todos os outros aplicativos agora. Cando estea concluído, saír da sesión ou reiniciar. Proceder á reparación agora?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="230"/>
        <source>User group membership was restored.</source>
        <translation>A pertenza ao grupo de usuarios foi restaurada.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="235"/>
        <source>Mozilla settings were reset.</source>
        <translation>A configuración do Mozilla foi restablecida.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="250"/>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Autologin options</source>
        <translation>Opcións de acceso automático</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>O acceso automático foi desactivado para a conta &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>O acceso automático foi activado para a conta &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>É necesario especificar un destino onde &apos;copiar a&apos;. Non é posible copar para o escritorio da sesión.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Antes de copiar, pechar todos os outros aplicativos. Certificarse de que o destino de &apos;copiar a&apos; é suficientemente grande para recibir todos os ficheiros a copiar. Copiar entre escritorios pode escribir por riba de, ou borrar, ficheiros ou preferencias do escritorio de destino. Continuar?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Synchronizing desktop...</source>
        <translation>Sincronizando escritorio...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>Copying desktop...</source>
        <translation>Copiando escritorio...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>O nome do usuario ten que te rpolo menos 2 caracteres. Escoller un nome do usuario máis cumprido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="370"/>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>The user name cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>O nome de usuario non pode conter caracteres especiais ou espazos. Escoller outro nome antes de proseguir.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Este nome xa está en uso. Introducir un nome diferente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="380"/>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Os contrasinais non coinciden. Intentar de novo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <location filename="../mainwindow.cpp" line="441"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>O contrasinal ten que ter polo menos 2 caracteres. Escoller un contrasinal máis longo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>The user was added ok.</source>
        <translation>O usuario foi engadido correctamente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>Failed to add the user.</source>
        <translation>Fallou engadir ao usuario.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>Password successfully changed.</source>
        <translation>O contrasinal foi cambiado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>Failed to change password.</source>
        <translation>Fallou o cambio do contrasinal.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="465"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Esta acción non pode ser revertida. Eliminar o usuario %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>The user has been deleted.</source>
        <translation>O usuario foi eliminado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="486"/>
        <source>Failed to delete the user.</source>
        <translation>A eliminación do usuario fallou.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>O nome do grupo ten que ter polo menos 2 caracteres. Escoller un nome máus comprimido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="505"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>O nome do grupo ten que estar en minúsculas e
non pode econter caracteres especiais ou espazos.
Escoller outro nome.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="513"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Este nome de grupo xa existe. Introducir un nome diferente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>The system group was added ok.</source>
        <translation>O grupo foi engadido correctamente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>Failed to add the system group.</source>
        <translation>Fallou engadir o grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="538"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Esta acción non pode ser revertida. Eliminar o grupo %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>This action cannot be undone. Are you sure you want to delete the following groups: %1?</source>
        <translation>Esta acción non pode ser revertida. Estás seguro de que queres eliminar os seguintes grupos: %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>Failed to delete the group.</source>
        <translation>Fallou a eliminación do grupo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>Group: %1</source>
        <translation>Grupo: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="552"/>
        <source>The group has been deleted.</source>
        <translation>O grupo foi eliminado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="552"/>
        <source>The groups have been deleted.</source>
        <translation>Os grupos foron eliminados.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="569"/>
        <source>The changes have been applied.</source>
        <translation>Os cambios foron aplicados.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="571"/>
        <source>Failed to apply group changes</source>
        <translation>A aplicación dos cambios fallou</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="589"/>
        <source>The selected user name is currently in use.</source>
        <translation>O nome do usuario seleccioando está en uso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="590"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Para renomear este usuario, saír da sesión e volver a entrar con outra conta de usuario.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="609"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Este nome xa existe no sistema. Introducir un nome diferente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="618"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Fallo ao renomear o usuario. Certificarse de que o usuario non está en sesión; pode ser necesario reiniciar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="651"/>
        <source>The user was renamed.</source>
        <translation>O usuario foi renomeado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <location filename="../mainwindow.cpp" line="691"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Sincronizando escritorio...feito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="665"/>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>Copying desktop...ok</source>
        <translation>Copiando escritorio...concluído</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="697"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Sincronizando escritorio...fallou</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="699"/>
        <source>Copying desktop...failed</source>
        <translation>Copiando escritorio...fallou</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="718"/>
        <source>Confirmation</source>
        <translation>Confirmación</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="719"/>
        <source>Process not done. Are you sure you want to quit the application?</source>
        <translation>Proceso non rematado. Estás seguro de que queres saír da aplicación?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="969"/>
        <source>About %1</source>
        <translation>Sobre %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="970"/>
        <source>Version: </source>
        <translation>Versión</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="971"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Configuración simple dos usuarios para o MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="973"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="974"/>
        <source>%1 License</source>
        <translation>Licenza de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="988"/>
        <source>%1 Help</source>
        <translation>Axuda para %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1005"/>
        <source>Select folder to copy to</source>
        <translation>Seleccionar cartafol para onde copiar</translation>
    </message>
</context>
<context>
    <name>PassEdit</name>
    <message>
        <location filename="../passedit.cpp" line="162"/>
        <source>Negligible</source>
        <translation>Insignificante</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="162"/>
        <source>Very weak</source>
        <translation>Moito débil</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="162"/>
        <source>Weak</source>
        <translation>Débil</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="163"/>
        <source>Moderate</source>
        <translation>Moderado</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="163"/>
        <source>Strong</source>
        <translation>Forte</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="163"/>
        <source>Very strong</source>
        <translation>Moito forte</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="164"/>
        <source>Password strength: %1</source>
        <translation>Forza do contrasinal: %1</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="200"/>
        <source>Hide the password</source>
        <translation>Agochar o contrasinal</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="200"/>
        <source>Show the password</source>
        <translation>Amosar o contrasinal</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="50"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <location filename="../about.cpp" line="61"/>
        <source>Changelog</source>
        <translation>Rexistro dos cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <location filename="../main.cpp" line="74"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>O usuario parece ser root; para usar este programa, pechar a sesión e iniciar sesión como usuario normal.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You must run this program with admin access.</source>
        <translation>Debes executar este programa con acceso de administrador.</translation>
    </message>
</context>
</TS>
